# docker_xtras role




This ansible-role for dealing with after the creation of the the docker images to fix/add extra tasks before starting the nedded containers.

At the moment, the tasks included are:
- **disable the CUPS service**
- **set folders permissions**, because sometimes, mounting a countainer folder, we need to fix it's permissions before running it.


## Requirements
- To have [ansible](https://docs.ansible.com/ansible/latest/installation_guide/installation_distros.html) installed at your system.


## Configuration
You need to set some configuration for this to work
- ### ansible.cfg
  You have to edit the **ansible.cfg** file to your needs for accessing your target.
  - #### remote_user
    You need to set the **remote_user** configuration for accessing the target host.

    Example: [remote_user](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/ansible.cfg#L227)

- ### HOST_VARS
  In order to access your target host, you need to create/edit your **inventories/host_vars/<YOUR_HOST_NAME>.yml**
  - #### ansible_become_pass
    You need to set the **sudo** password from the user setted on **remote_user** for installing packages and etc. at the target.

    Example: [ansible_become_pass](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/inventories/host_vars/example_server.yml#L5)

- ### HOSTS
  You need to provide a **group** in which your target belongs to with the same name setted for **inventories/host_vars/<YOUR_HOST_NAME>.yml**.

  There you can add/edit the target address/IP.

  Example: [hosts](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/inventories/hosts)


## Role Variables
Here are the variables setted:

- ### From CUPS service
  Here are the variables needed to disable the **CUPS** service at the target host.
  - #### c3infodesk_deployment_repository_dest_folder
    - This should be a **string** entry with the path of the folder where is located the folder from the project that you are using this role to fix things before starting the container.
    - This variable is also needed for setting the [clone-repository](https://git.cccv.de/fejao/c3infodesk-deployment-role-clone-repositories) role.
    - **DEFAULT**: *"/tmp/test"*

  - #### c3infodesk_deployment_docker_xtras_cups_disable
    - This should be a **boolean** entry with the value from if you want or not to disable the **CUPS** service at the target host.
    - **DEFAULT**: *false*

  - #### c3infodesk_deployment_docker_xtras_cups_mask
    - This should be a **boolean** entry with the value from if you want or not to mask the **CUPS** service at the target host.
    - **DEFAULT**: *false*

  - #### c3infodesk_deployment_docker_xtras_cups_disable_debug
    - This should be a **boolean** entry with the value from if you want or not to see the **debug** outputs from setting the **CUPS** at the target host.
    - **DEFAULT**: *false*

- ### From setting the folders permissions
  Here are the variables needed to change/update the folders permissions.
  - #### c3infodesk_deployment_docker_xtras_fix_folders_permissions
    - This should be a **boolean** entry with the value from if you want or not to fix folder permissions at the target host.
    - **DEFAULT**: *false*

  - #### c3infodesk_deployment_docker_xtras_fix_folders_permissions_debug
    - This should be a **boolean** entry with the value from if you want or not to see the **debug** outputs from setting the folders permissions at the target host.
    - **DEFAULT**: *false*

  - #### c3infodesk_deployment_docker_xtras_fix_folders_permissions_list
    - This should be a **list** entry with the the information of the folders that needes to be have new permissions setted.
    - This list include entries with the default keys:
      - **folder_path**
        - The path from the location of the **docker mounted folder** that needs new permissions.
      - **folder_mode**
        - This should be an **octal** entry with the mode from the folder to be updated The mode that .
    - **DEFAULT**: The default values are seeted for the [c3buttons](https://git.cccv.de/fejao/c3buttons) project.
      ```yaml
      c3infodesk_deployment_docker_xtras_fix_folders_permissions_list:
        - folder_path: docker/grafana/data
          folder_mode: "0777"
      ```


## Dependencies
The role dependencies are:
  - [dependencies(role)](https://git.cccv.de/fejao/c3infodesk-deployment-role-dependencies)
  - [clone_repositories](https://git.cccv.de/fejao/c3infodesk-deployment-role-clone-repositories)
  - [docker_images](https://git.cccv.de/fejao/c3infodesk-deployment-role-docker-images)


## Example Playbook

- ### Using the provided example
    For using the example playbook **[playbooks/examples/example_04_docker_images.yml](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/playbooks/examples/example_04_docker_images.yml)** file you only need to:
    - Change the user at the **[ansible.cfg](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/ansible.cfg)** file at the field **[remote_user](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/ansible.cfg#L227)** for acessing your target.
    - Update the file **[inventories/host_vars/example_server.yml](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/inventories/host_vars/example_server.yml)** and change the value for **[ansible_become_pass](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/inventories/host_vars/example_server.yml#L5)** from the **[remote_user](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/ansible.cfg#L227)**
    - Update the **[inventories/hosts](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/inventories/hosts)** file and change the **[example_server](https://git.cccv.de/fejao/c3infodesk-deployment/-/blob/main/inventories/hosts#L2)** with the IP address from your target.


    And run the command:
  ```bash
  ansible-playbook -i inventories/hosts playbooks/example_c3infodesk_printer/c3infodesk_printer_04_docker_xtras.yml
  ```

- ### Setting your own example
  After setting your variables at **inventories/host_vars/<HOST_NAME>**, you can add this role to your playbook as a regular role.

  Here is an example using the **<HOST_NAME>** as **test_servers**

  ```yaml
  - hosts:
      - test_servers
    roles:
      - roles/c3infodesk-deployment-role-docker-xtras
  ```

  And call the playbook as:

  ```bash
  ansible-playbook -i <INVENTORY> <PLAYBOOK_NAME>.yml
  ```


## Testing
For testing this role, please reference [how to use molecule tests](https://git.cccv.de/fejao/c3infodesk-deployment-role-docker-xtras/-/tree/main/molecule)


## License

MIT / BSD


## Author Information
[https://chaos.social/@fejao](https://chaos.social/@fejao)
